@@ -1,10 +1,9 @@
 package POE::Component::IRC::Plugin::YouTube::MovieFindStore;
 
-use 5.008008;
-use strict;
 use warnings;
+use strict;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use File::Spec;
 use POE::Component::IRC::Plugin qw( :ALL );
@@ -737,21 +736,50 @@ the explanation of why we failed.
 L<POE::Component::IRC>, L<POE::Component::IRC::Plugin>,
 L<POE::Component::WWW::YouTube::VideoURI>
 
-=head1 BUGS
-
-None known.
-
 =head1 AUTHOR
 
-Zoffix Znet, E<lt>zoffix@cpan.orgE<gt>
+Zoffix Znet, C<< <zoffix at cpan.org> >>
+(L<http://zoffix.com>, L<http://haslayout.net>)
 
-=head1 COPYRIGHT AND LICENSE
+=head1 BUGS
 
-Copyright (C) 2008 by Zoffix Znet
+Please report any bugs or feature requests to C<bug-poe-component-irc-plugin-youtube-moviefindstore at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=POE-Component-IRC-Plugin-YouTube-MovieFindStore>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.8 or,
-at your option, any later version of Perl 5 you may have available.
+=head1 SUPPORT
 
+You can find documentation for this module with the perldoc command.
+
+    perldoc POE::Component::IRC::Plugin::YouTube::MovieFindStore
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=POE-Component-IRC-Plugin-YouTube-MovieFindStore>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/POE-Component-IRC-Plugin-YouTube-MovieFindStore>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/POE-Component-IRC-Plugin-YouTube-MovieFindStore>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/POE-Component-IRC-Plugin-YouTube-MovieFindStore>
+
+=back
+
+=head1 COPYRIGHT & LICENSE
+
+Copyright 2008 Zoffix Znet, all rights reserved.
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
 =cut
